@@ -16,7 +16,9 @@
 """
 
 # Import the toolkit specific version
-from toolkit import toolkit_object
+from __future__ import absolute_import
+
+from .toolkit import toolkit_object
 Clipboard = toolkit_object('clipboard:Clipboard')
 
 # Create a singleton clipboard object for convenience
