@@ -17,7 +17,7 @@
 
 """ Pyface 'DockWindow' support.
 
-    This package implements a Pyface 'dockable' window component that allows
+    This package provides a Pyface 'dockable' window component that allows
     child windows to be reorganized within the DockWindow using drag and drop.
     The component also allows multiple sub-windows to occupy the same
     sub-region of the DockWindow, in which case each sub-window appears as a
@@ -62,15 +62,10 @@ from pyface.wx.drag_and_drop \
 from pyface.message_dialog \
     import error as warning
 
-from dock_sizer \
-    import DockSizer, DockControl, DockRegion, DockStyle, DockSplitter, \
-           no_dock_info, clear_window, features
-
-from idockable \
-    import IDockable
-
-from idock_ui_provider \
-    import IDockUIProvider
+from .dock_sizer import DockSizer, DockControl, DockRegion, DockStyle, \
+    DockSplitter, no_dock_info, clear_window, features
+from .idockable import IDockable
+from .idock_ui_provider import IDockUIProvider
 
 is_mac = (sys.platform == 'darwin')
 
@@ -165,8 +160,9 @@ class DockWindowHandler ( HasPrivateTraits ):
             # If DockControl was closed, then reset it to point to the new
             # control:
             if close:
-                dock_control.set( control = control,
-                                  style   = parent.owner.style )
+                dock_control.trait_set(
+                    control = control,
+                    style   = parent.owner.style)
                 dockable.dockable_init_dockcontrol( dock_control )
                 return dock_control
 
@@ -833,8 +829,8 @@ class DockWindow ( HasPrivateTraits ):
             name = control_info.name.strip()
             if name != '':
                 object.name = name
-            object.set( **control_info.get( 'user_name',
-                                            'style', 'user_style' ) )
+            object.trait_set(**control_info.get('user_name', 'style',
+                                                'user_style'))
             self.update_layout()
 
     #---------------------------------------------------------------------------
@@ -897,7 +893,7 @@ class DockWindow ( HasPrivateTraits ):
         """
         layouts = self._get_layouts()
         if layouts is not None:
-            return layouts.keys()
+            return list(layouts.keys())
 
         return []
 
