@@ -60,7 +60,7 @@ class ActionSchema(Schema):
         return []
 
     def create(self, children):
-        """ Create the appropriate PyFace Action instance. """
+        """ Create the appropriate Pyface Action instance. """
 
         traits = dict(id=self.id)
         return self.action_factory(**traits)
@@ -88,11 +88,19 @@ class MenuSchema(Schema):
     # The menu's user visible name.
     name = Unicode
 
+    # Does the menu require a separator before the menu item?
+    separator = Bool(False)
+
+    # The default action for tool button when shown in a toolbar (Qt only)
+    action = Instance(Action)
+
     # A factory for instantiating a pyface MenuManager.
     menu_manager_factory = Callable(MenuManager)
 
     def create(self, children):
-        traits = dict(id=self.id, name=self.name)
+        traits = dict(id=self.id, name=self.name, separator=self.separator)
+        if self.action:
+            traits['action'] = self.action
         return self.menu_manager_factory(*children, **traits)
 
 
@@ -139,7 +147,7 @@ class ToolBarSchema(Schema):
 
     def create(self, children):
         traits = dict(id=self.id, name=self.name, image_size=self.image_size,
-                      orientation=self.orientation, 
+                      orientation=self.orientation,
                       show_divider=self.show_divider,
                       show_tool_names=self.show_tool_names)
         return self.tool_bar_manager_factory(*children, **traits)
