@@ -1,9 +1,18 @@
+# Copyright (c) 2010-18, Enthought, Inc.
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in enthought/LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
+
 # Enthought library imports.
-from pyface.tasks.api import Editor, Task, TaskPane
 from traits.api import Bool, Instance, Property, Str, cached_property
 
 # Local imports.
-from listening_action import ListeningAction
+from pyface.tasks.api import Editor, Task, TaskPane
+from pyface.action.listening_action import ListeningAction
 
 
 class TaskAction(ListeningAction):
@@ -21,7 +30,7 @@ class TaskAction(ListeningAction):
 
     # The Task with which the action is associated. Set by the framework.
     task = Instance(Task)
-    
+
     ###########################################################################
     # Protected interface.
     ###########################################################################
@@ -38,7 +47,7 @@ class TaskAction(ListeningAction):
 class TaskWindowAction(TaskAction):
     """ An Action that makes a callback to a Task's window.
     """
-    
+
     #### ListeningAction interface ############################################
 
     object = Property(depends_on='task.window')
@@ -51,7 +60,7 @@ class TaskWindowAction(TaskAction):
         if self.task:
             return self.task.window
         return None
-    
+
 
 class CentralPaneAction(TaskAction):
     """ An Action that makes a callback to a Task's central pane.
@@ -72,7 +81,7 @@ class CentralPaneAction(TaskAction):
 
     @cached_property
     def _get_central_pane(self):
-        if self.task:
+        if self.task and self.task.window is not None:
             return self.task.window.get_central_pane(self.task)
         return None
 
@@ -102,7 +111,7 @@ class DockPaneAction(TaskAction):
 
     @cached_property
     def _get_dock_pane(self):
-        if self.task:
+        if self.task and self.task.window is not None:
             return self.task.window.get_dock_pane(self.dock_pane_id, self.task)
         return None
 
@@ -113,7 +122,7 @@ class DockPaneAction(TaskAction):
 class EditorAction(CentralPaneAction):
     """ An action that makes a callback to the active editor in an editor pane.
     """
-    
+
     #### ListeningAction interface ############################################
 
     object = Property(depends_on='active_editor')
@@ -121,8 +130,9 @@ class EditorAction(CentralPaneAction):
     #### EditorAction interface ###############################################
 
     # The active editor in the central pane with which the action is associated.
-    active_editor = Property(Instance(Editor), 
-                             depends_on='central_pane.active_editor')
+    active_editor = Property(
+        Instance(Editor), depends_on='central_pane.active_editor'
+    )
 
     ###########################################################################
     # Protected interface.
