@@ -1,6 +1,6 @@
 # Enthought library imports.
 from traits.api import Any, DelegatesTo, HasTraits, Instance, Interface, \
-    implements
+    provides
 
 
 class ITaskWindowBackend(Interface):
@@ -10,10 +10,10 @@ class ITaskWindowBackend(Interface):
     layout functionality.
     """
 
-    # The root control of the TaskWindow to which the layout belongs.
+    #: The root control of the TaskWindow to which the layout belongs.
     control = Any
 
-    # The TaskWindow to which the layout belongs.
+    #: The TaskWindow to which the layout belongs.
     window = Instance('pyface.tasks.task_window.TaskWindow')
 
     ###########################################################################
@@ -36,7 +36,7 @@ class ITaskWindowBackend(Interface):
         """
 
     def show_task(self, state):
-        """ Assumming no task is currently active, show the controls of the
+        """ Assuming no task is currently active, show the controls of the
             specified TaskState.
         """
 
@@ -52,11 +52,11 @@ class ITaskWindowBackend(Interface):
         """
 
 
+@provides(ITaskWindowBackend)
 class MTaskWindowBackend(HasTraits):
     """ Mixin containing common coe for toolkit-specific implementations.
     """
 
-    implements(ITaskWindowBackend)
 
     #### 'ITaskWindowBackend' interface #######################################
 
