@@ -12,8 +12,8 @@ def before_after_sort(items):
     The sort is topological. If an item does not specify a 'before' or 'after',
     it is placed after the preceding item.
 
-    If a cycle is found in the dependecies, a warning is logged and the order of
-    the items is undefined.
+    If a cycle is found in the dependencies, a warning is logged and the order
+    of the items is undefined.
     """
     # Handle a degenerate case for which the logic below will fail (because
     # prev_item will not be set).
@@ -79,7 +79,7 @@ def topological_sort(pairs):
     
     # Descend through graph, removing parents as we go.
     for parent in result:
-        if graph.has_key(parent):
+        if parent in graph:
             for child in graph[parent]:
                 num_parents[child] -= 1
                 if num_parents[child] == 0:
@@ -89,5 +89,5 @@ def topological_sort(pairs):
     # If there's a cycle, just throw in whatever is left over.
     has_cycle = bool(graph)
     if has_cycle:
-        result.extend(graph.keys())
+        result.extend(list(graph.keys()))
     return result, has_cycle
