@@ -11,5 +11,9 @@
 # Author: Enthought, Inc.
 # Description: <Enthought pyface package component>
 #------------------------------------------------------------------------------
-from timer import Timer
-from do_later import do_later, do_after, DoLaterTimer
+
+from __future__ import absolute_import
+
+from .do_later import do_later, do_after, DoLaterTimer
+from .i_timer import ICallbackTimer, IEventTimer, ITimer
+from .timer import CallbackTimer, EventTimer, Timer
