@@ -1,19 +1,24 @@
-#------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
+# Copyright (c) 2019, Enthought, Inc.
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD license.
-# However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
-
+# However, when used with the GPL version of PyQt the additional terms described
+# in the PyQt GPL exception also apply.
 #
 # Author: Riverbank Computing Limited
 # Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+
 """ The PyQt specific implementations the action manager internal classes. """
 
 
-# Standard libary imports.
-from inspect import getargspec
+# Standard library imports.
+import six
+if six.PY2:
+    from inspect import getargspec
+else:
+    # avoid deprecation warning
+    from inspect import getfullargspec as getargspec
 
 # Major package imports.
 from pyface.qt import QtGui, QtCore
@@ -25,6 +30,18 @@ from traits.api import Any, Bool, HasTraits
 from pyface.action.action_event import ActionEvent
 
 
+class PyfaceWidgetAction(QtGui.QWidgetAction):
+
+    def __init__(self, parent, action):
+        super(PyfaceWidgetAction, self).__init__(parent)
+        self.action = action
+
+    def createWidget(self, parent):
+        widget = self.action.create_control(parent)
+        widget._action = self.action
+        return widget
+
+
 class _MenuItem(HasTraits):
     """ A menu item representation of an action item. """
 
@@ -49,6 +66,9 @@ class _MenuItem(HasTraits):
     # The toolkit control.
     control = Any()
 
+    # The toolkit control id.
+    control_id = None
+
     ###########################################################################
     # 'object' interface.
     ###########################################################################
@@ -62,7 +82,10 @@ class _MenuItem(HasTraits):
         # FIXME v3: This is a wx'ism and should be hidden in the toolkit code.
         self.control_id = None
 
-        if action.image is None:
+        if action.style == 'widget':
+            self.control = PyfaceWidgetAction(parent, action)
+            menu.addAction(self.control)
+        elif action.image is None:
             self.control = menu.addAction(action.name, self._qt4_on_triggered,
                     action.accelerator)
         else:
@@ -152,11 +175,11 @@ class _MenuItem(HasTraits):
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it. This is also
             # useful as Traits UI controllers *never* require the event.
-            args, varargs, varkw, dflts = getargspec(self.controller.perform)
+            argspec = getargspec(self.controller.perform)
 
             # If the only arguments are 'self' and 'action' then don't pass
             # the event!
-            if len(args) == 2:
+            if len(argspec.args) == 2:
                 self.controller.perform(action)
 
             else:
@@ -169,10 +192,10 @@ class _MenuItem(HasTraits):
             # Most of the time, action's do no care about the event (it
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it.
-            args, varargs, varkw, dflts = getargspec(action.perform)
+            argspec = getargspec(action.perform)
 
             # If the only argument is 'self' then don't pass the event!
-            if len(args) == 1:
+            if len(argspec.args) == 1:
                 action.perform()
 
             else:
@@ -245,6 +268,9 @@ class _Tool(HasTraits):
     # The toolkit control.
     control = Any()
 
+    # The toolkit control id.
+    control_id = None
+
     ###########################################################################
     # 'object' interface.
     ###########################################################################
@@ -257,18 +283,17 @@ class _Tool(HasTraits):
         self.tool_bar = tool_bar
         action = item.action
 
-        # FIXME v3: This is a wx'ism and should be hidden in the toolkit code.
-        self.control_id = None
-
-        if action.image is None:
+        if action.style == 'widget':
+            widget = action.create_control(tool_bar)
+            self.control = tool_bar.addWidget(widget)
+        elif action.image is None:
             self.control = tool_bar.addAction(action.name)
         else:
             size = tool_bar.iconSize()
             image = action.image.create_icon((size.width(), size.height()))
             self.control = tool_bar.addAction(image, action.name)
 
-        QtCore.QObject.connect(self.control, QtCore.SIGNAL('triggered()'),
-                               self._qt4_on_triggered)
+        self.control.triggered.connect(self._qt4_on_triggered)
 
         self.control.setToolTip(action.tooltip)
         self.control.setWhatsThis(action.description)
@@ -300,6 +325,9 @@ class _Tool(HasTraits):
         action.on_trait_change(self._on_action_enabled_changed, 'enabled')
         action.on_trait_change(self._on_action_visible_changed, 'visible')
         action.on_trait_change(self._on_action_checked_changed, 'checked')
+        action.on_trait_change(self._on_action_name_changed, 'name')
+        action.on_trait_change(self._on_action_accelerator_changed,
+                               'accelerator')
 
         # Detect if the control is destroyed.
         self.control.destroyed.connect(self._qt4_on_destroyed)
@@ -332,11 +360,11 @@ class _Tool(HasTraits):
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it. This is also
             # useful as Traits UI controllers *never* require the event.
-            args, varargs, varkw, dflts = getargspec(self.controller.perform)
+            argspec = getargspec(self.controller.perform)
 
             # If the only arguments are 'self' and 'action' then don't pass
             # the event!
-            if len(args) == 2:
+            if len(argspec.args) == 2:
                 self.controller.perform(action)
 
             else:
@@ -348,10 +376,10 @@ class _Tool(HasTraits):
             # Most of the time, action's do no care about the event (it
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it.
-            args, varargs, varkw, dflts = getargspec(action.perform)
+            argspec = getargspec(action.perform)
 
             # If the only argument is 'self' then don't pass the event!
-            if len(args) == 1:
+            if len(argspec.args) == 1:
                 action.perform()
 
             else:
@@ -389,6 +417,16 @@ class _Tool(HasTraits):
         if self.control is not None:
             self.control.setChecked(action.checked)
 
+    def _on_action_name_changed(self, action, trait_name, old, new):
+        """ Called when the name trait is changed on an action. """
+        if self.control is not None:
+            self.control.setText(action.name)
+
+    def _on_action_accelerator_changed(self, action, trait_name, old, new):
+        """ Called when the accelerator trait is changed on an action. """
+        if self.control is not None:
+            self.control.setShortcut(action.accelerator)
+
 
 class _PaletteTool(HasTraits):
     """ A tool palette representation of an action item. """
@@ -412,6 +450,10 @@ class _PaletteTool(HasTraits):
         action = self.item.action
         label = action.name
 
+        if action.style == "widget":
+            raise NotImplementedError(
+                "Qt does not support widgets in palettes")
+
         # Tool palette tools never have '...' at the end.
         if label.endswith('...'):
             label = label[:-3]
@@ -488,5 +530,3 @@ class _PaletteTool(HasTraits):
         action.perform(action_event)
 
         return
-
-#### EOF ######################################################################
