@@ -15,6 +15,7 @@ from pygments.lexer import RegexLexer, _TokenType, Text, Error
 from pygments.lexers import CLexer, CppLexer, PythonLexer, get_lexer_by_name
 from pygments.styles.default import DefaultStyle
 from pygments.token import Comment
+import six
 
 
 def get_tokens_unprocessed(self, text, stack=('root',)):
@@ -118,7 +119,7 @@ class BlockUserData(QtGui.QTextBlockUserData):
 
     def __init__(self, **kwds):
         QtGui.QTextBlockUserData.__init__(self)
-        for key, value in kwds.iteritems():
+        for key, value in kwds.items():
             setattr(self, key, value)
 
     def __repr__(self):
@@ -147,7 +148,7 @@ class PygmentsHighlighter(QtGui.QSyntaxHighlighter):
     def highlightBlock(self, qstring):
         """ Highlight a block of text.
         """
-        qstring = unicode(qstring)
+        qstring = six.text_type(qstring)
         prev_data = self.previous_block_data()
 
         if prev_data is not None:
@@ -186,7 +187,7 @@ class PygmentsHighlighter(QtGui.QSyntaxHighlighter):
         if token in self._formats:
             return self._formats[token]
         result = None
-        for key, value in self._style.style_for_token(token) .items():
+        for key, value in self._style.style_for_token(token).items():
             if value:
                 if result is None:
                     result = QtGui.QTextCharFormat()
