@@ -1,4 +1,3 @@
-#------------------------------------------------------------------------------
 # Copyright (c) 2011, Enthought, Inc.
 # All rights reserved.
 #
@@ -9,12 +8,12 @@
 # Thanks for using Enthought open source!
 #
 # Author: Evan Patterson
-#------------------------------------------------------------------------------
+
 
 # Standard library imports.
-import __builtin__
+import six.moves.builtins
 from code import compile_command, InteractiveInterpreter
-from cStringIO import StringIO
+from six.moves import cStringIO as StringIO
 import sys
 from time import time
 
@@ -27,16 +26,14 @@ from traits.api import Event, provides
 from traits.util.clean_strings import python_name
 
 # Local imports.
-from code_editor.pygments_highlighter import PygmentsHighlighter
-from console.api import BracketMatcher, CallTipWidget, CompletionLexer, \
+from .code_editor.pygments_highlighter import PygmentsHighlighter
+from .console.api import BracketMatcher, CallTipWidget, CompletionLexer, \
     HistoryConsoleWidget
 from pyface.i_python_shell import IPythonShell, MPythonShell
 from pyface.key_pressed_event import KeyPressedEvent
-from widget import Widget
+from .widget import Widget
+import six
 
-#-------------------------------------------------------------------------------
-# 'PythonShell' class:
-#-------------------------------------------------------------------------------
 
 @provides(IPythonShell)
 class PythonShell(MPythonShell, Widget):
@@ -58,16 +55,10 @@ class PythonShell(MPythonShell, Widget):
     # FIXME v3: Either make this API consistent with other Widget sub-classes
     # or make it a sub-class of HasTraits.
     def __init__(self, parent, **traits):
-        super(PythonShell, self).__init__(**traits)
+        super(PythonShell, self).__init__(parent=parent, **traits)
 
         # Create the toolkit-specific control that represents the widget.
-        self.control = self._create_control(parent)
-
-        # Set up to be notified whenever a Python statement is executed:
-        self.control.executed.connect(self._on_command_executed)
-
-        # Handle dropped objects.
-        _DropEventEmitter(self.control).signal.connect(self._on_obj_drop)
+        self._create()
 
     #--------------------------------------------------------------------------
     # 'IPythonShell' interface
@@ -82,6 +73,32 @@ class PythonShell(MPythonShell, Widget):
     def execute_file(self, path, hidden=True):
         self.control.execute_file(path, hidden=hidden)
 
+    def get_history(self):
+        """ Return the current command history and index.
+
+        Returns
+        -------
+        history : list of str
+            The list of commands in the new history.
+        history_index : int from 0 to len(history)
+            The current item in the command history navigation.
+        """
+        return self.control._history, self.control._history_index
+
+    def set_history(self, history, history_index):
+        """ Replace the current command history and index with new ones.
+
+        Parameters
+        ----------
+        history : list of str
+            The list of commands in the new history.
+        history_index : int
+            The current item in the command history navigation.
+        """
+        if not 0 <= history_index <= len(history):
+            history_index = len(history)
+        self.control._set_history(history, history_index)
+
     #--------------------------------------------------------------------------
     # 'IWidget' interface.
     #--------------------------------------------------------------------------
@@ -89,6 +106,24 @@ class PythonShell(MPythonShell, Widget):
     def _create_control(self, parent):
         return PyfacePythonWidget(self, parent)
 
+    def _add_event_listeners(self):
+        super(PythonShell, self)._add_event_listeners()
+
+        # Connect signals for events.
+        self.control.executed.connect(self._on_command_executed)
+        self._event_filter.signal.connect(self._on_obj_drop)
+
+    def _remove_event_listeners(self):
+        if self.control is not None:
+            # Disconnect signals for events.
+            self.control.executed.connect(self._on_command_executed)
+            self._event_filter.signal.disconnect(self._on_obj_drop)
+
+        super(PythonShell, self)._remove_event_listeners()
+
+    def __event_filter_default(self):
+        return _DropEventEmitter(self.control)
+
     #--------------------------------------------------------------------------
     # 'Private' interface.
     #--------------------------------------------------------------------------
@@ -100,7 +135,7 @@ class PythonShell(MPythonShell, Widget):
         name = 'dragged'
 
         if hasattr(obj, 'name') \
-           and isinstance(obj.name, basestring) and len(obj.name) > 0:
+           and isinstance(obj.name, six.string_types) and len(obj.name) > 0:
             py_name = python_name(obj.name)
 
             # Make sure that the name is actually a valid Python identifier.
@@ -115,10 +150,6 @@ class PythonShell(MPythonShell, Widget):
         self.control._control.setFocus()
 
 
-#-------------------------------------------------------------------------------
-# 'PythonWidget' class:
-#-------------------------------------------------------------------------------
-
 class PythonWidget(HistoryConsoleWidget):
     """ A basic in-process Python interpreter.
     """
@@ -329,7 +360,8 @@ class PythonWidget(HistoryConsoleWidget):
         """ Attempts to execute file with 'path'. If 'hidden', no output is
             shown.
         """
-        self.execute('execfile(%s)' % repr(path), hidden=hidden)
+
+        self.execute("exec(open(%s).read())" % repr(path), hidden=hidden)
 
     def reset(self):
         """ Resets the widget to its initial state. Similar to ``clear``, but
@@ -375,8 +407,8 @@ class PythonWidget(HistoryConsoleWidget):
             if len(leftover) == 1:
                 leftover = leftover[0]
                 if symbol is None:
-                    names = self.interpreter.locals.keys()
-                    names += __builtin__.__dict__.keys()
+                    names = list(self.interpreter.locals.keys())
+                    names += list(six.moves.builtins.__dict__.keys())
                 else:
                     names = dir(symbol)
                 completions = [ n for n in names if n.startswith(leftover) ]
@@ -408,14 +440,14 @@ class PythonWidget(HistoryConsoleWidget):
         """ Find a python object in the interpeter namespace from a context (a
             list of names).
         """
-        context = map(str, context)
+        context = list(map(str, context))
         if len(context) == 0:
             return None, context
 
         base_symbol_string = context[0]
         symbol = self.interpreter.locals.get(base_symbol_string, None)
         if symbol is None:
-            symbol = __builtin__.__dict__.get(base_symbol_string, None)
+            symbol = six.moves.builtins.__dict__.get(base_symbol_string, None)
         if symbol is None:
             return None, context
 
@@ -554,10 +586,6 @@ class PyfacePythonWidget(PythonWidget):
         super(PyfacePythonWidget, self).keyPressEvent(event)
 
 
-#-------------------------------------------------------------------------------
-# '_DropEventFilter' class:
-#-------------------------------------------------------------------------------
-
 class _DropEventEmitter(QtCore.QObject):
     """ Handle object drops on widget. """
     signal = QtCore.Signal(object)
