@@ -6,17 +6,16 @@ from pyface.tasks.i_editor_area_pane import IEditorAreaPane, \
     MEditorAreaPane
 from traits.api import Bool, cached_property, Callable, Dict, Instance, List, \
     on_trait_change, Property, provides, Str
-from pyface.qt import QtCore, QtGui
-from pyface.action.api import Action, Group
+from pyface.qt import is_qt4, QtCore, QtGui
+from pyface.action.api import Action, Group, MenuManager
 from pyface.tasks.task_layout import PaneItem, Tabbed, Splitter
-from traitsui.api import Menu
-from traitsui.mimedata import PyMimeData
+from pyface.mimedata import PyMimeData
 from pyface.api import FileDialog
 from pyface.constant import OK
 from pyface.drop_handler import IDropHandler, BaseDropHandler, FileDropHandler
 
 # Local imports.
-from task_pane import TaskPane
+from .task_pane import TaskPane
 
 ###############################################################################
 # 'SplitEditorAreaPane' class.
@@ -113,8 +112,9 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
     def activate_editor(self, editor):
         """ Activates the specified editor in the pane.
         """
-        self.active_tabwidget = editor.control.parent().parent()
-        self.active_tabwidget.setCurrentWidget(editor.control)
+        active_tabwidget = editor.control.parent().parent()
+        active_tabwidget.setCurrentWidget(editor.control)
+        self.active_tabwidget = active_tabwidget
         editor_widget = editor.control.parent()
         editor_widget.setVisible(True)
         editor_widget.raise_()
@@ -178,7 +178,7 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
         pos : position (in global coordinates) where the context menu was
         requested
         """
-        menu = Menu()
+        menu = MenuManager()
         splitter = None
 
         splitter = None
@@ -209,12 +209,12 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
         # add collapse action (only show for collapsible splitters)
         if splitter.is_collapsible():
             if splitter is splitter.parent().leftchild:
-                if splitter.parent().orientation() is QtCore.Qt.Horizontal:
+                if splitter.parent().orientation() == QtCore.Qt.Horizontal:
                     text = 'Merge with right pane'
                 else:
                     text = 'Merge with bottom pane'
             else:
-                if splitter.parent().orientation() is QtCore.Qt.Horizontal:
+                if splitter.parent().orientation() == QtCore.Qt.Horizontal:
                     text = 'Merge with left pane'
                 else:
                     text = 'Merge with top pane'
@@ -269,7 +269,7 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
         mod = 'Ctrl+' if sys.platform == 'darwin' else 'Alt+'
         mapper = QtCore.QSignalMapper(self.control)
         mapper.mapped.connect(self._activate_tab)
-        for i in xrange(1, 10):
+        for i in range(1, 10):
             sequence = QtGui.QKeySequence(mod + str(i))
             shortcut = QtGui.QShortcut(sequence, self.control)
             shortcut.activated.connect(mapper.map)
@@ -330,7 +330,7 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
         """Set the active tabwidget after an application-level change in focus.
         """
 
-        if new:
+        if new is not None:
             if isinstance(new, DraggableTabWidget):
                 if new.editor_area == self:
                     self.active_tabwidget = new
@@ -344,14 +344,24 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
                 for editor in self.editors:
                     control = editor.control
                     if control is not None and control.isAncestorOf(new):
-                        self.active_tabwidget = \
+                        active_tabwidget = \
                             self._find_ancestor_draggable_tab_widget(control)
-                        self.active_tabwidget.setCurrentWidget(control)
-                        # Set active_editor at the end so that the notification
-                        # occurs when everything is ready.
-                        self.active_editor = editor
+                        active_tabwidget.setCurrentWidget(control)
+                        self.active_tabwidget = active_tabwidget
                         break
 
+    def _active_tabwidget_changed(self, new):
+        """Set the active editor whenever the active tabwidget updates.
+        """
+
+        if new is None or new.parent().is_empty():
+            active_editor = None
+        else:
+            active_editor = self._get_editor(new.currentWidget())
+
+        self.active_editor = active_editor
+
+
 ###############################################################################
 # Auxiliary classes.
 ###############################################################################
@@ -804,10 +814,15 @@ class DraggableTabWidget(QtGui.QTabWidget):
     def contextMenuEvent(self, event):
         """ To show collapse context menu even on empty tabwidgets
         """
-        global_pos = self.mapToGlobal(event.pos())
-        menu = self.editor_area.get_context_menu(pos=global_pos)
-        qmenu = menu.create_menu(self)
-        qmenu.exec_(global_pos)
+        local_pos = event.pos()
+        if (self.empty_widget is not None or
+                self.tabBar().rect().contains(local_pos)):
+            # Only display if we are in the tab bar region or the whole area if
+            # we are displaying the default empty widget.
+            global_pos = self.mapToGlobal(local_pos)
+            menu = self.editor_area.get_context_menu(pos=global_pos)
+            qmenu = menu.create_menu(self)
+            qmenu.exec_(global_pos)
 
     def dragEnterEvent(self, event):
         """ Re-implemented to highlight the tabwidget on drag enter
@@ -919,16 +934,23 @@ class TabDragObject(object):
         painter.fillRect(result_pixmap.rect(), QtCore.Qt.lightGray)
         painter.setCompositionMode(QtGui.QPainter.CompositionMode_SourceOver)
 
-        optTabBase = QtGui.QStyleOptionTabBarBaseV2()
+        optTabBase = QtGui.QStyleOptionTabBarBase()
         optTabBase.initFrom(tabBar)
         painter.drawPrimitive(QtGui.QStyle.PE_FrameTabBarBase, optTabBase)
 
         # region of active tab
-        pixmap1 = QtGui.QPixmap.grabWidget(tabBar, tab_rect)
-        painter.drawPixmap(0,0,pixmap1) #tab_rect.topLeft(), pixmap1)
+        if is_qt4:  # grab wasn't introduced until Qt5
+            pixmap1 = QtGui.QPixmap.grabWidget(tabBar, tab_rect)
+        else:
+            pixmap1 = tabBar.grab(tab_rect)
+
+        painter.drawPixmap(0, 0, pixmap1)
 
         # region of the page widget
-        pixmap2 = QtGui.QPixmap.grabWidget(self.widget)
+        if is_qt4:
+            pixmap2 = QtGui.QPixmap.grabWidget(self.widget)
+        else:
+            pixmap2 = self.widget.grab()
         painter.drawPixmap(0, tab_rect.height(), size.width(), size.height(), pixmap2)
 
         # finish painting
