@@ -13,6 +13,7 @@
 
 
 # Major package imports.
+from __future__ import print_function
 from pyface.qt import QtCore, QtGui
 
 # Enthought library imports.
@@ -78,8 +79,7 @@ class Wizard(MWizard, Dialog):
 
         # Necessary for 'nonmodal'. See Dialog for more info.
         if self.style == 'nonmodal':
-            QtCore.QObject.connect(control, QtCore.SIGNAL('finished(int)'),
-                                   self._finished_fired)
+            control.finished.connect(self._finished_fired)
 
         if self.size != (-1, -1):
             size = QtCore.QSize(*self.size)
@@ -91,8 +91,7 @@ class Wizard(MWizard, Dialog):
 
         if self.help_id:
             control.setOption(QtGui.QWizard.HaveHelpButton)
-            QtCore.QObject.connect(control, QtCore.SIGNAL('helpRequested()'),
-                    self._help_requested)
+            control.helpRequested.connect(self._help_requested)
 
         # Add the initial pages.
         for page in self.pages:
@@ -112,7 +111,7 @@ class Wizard(MWizard, Dialog):
         """ Called when the 'Help' button is pressed. """
 
         # FIXME: Hook into a help system.
-        print "Show help for", self.help_id
+        print("Show help for", self.help_id)
 
     #### Trait handlers #######################################################
 
@@ -168,8 +167,7 @@ class _Wizard(QtGui.QWizard):
         self._controller = pyface_wizard.controller
         self._ids = {}
 
-        QtCore.QObject.connect(self, QtCore.SIGNAL('currentIdChanged(int)'),
-                self._update_controller)
+        self.currentIdChanged.connect(self._update_controller)
 
     def addWizardPage(self, page):
         """ Add a page that provides IWizardPage. """
