@@ -21,10 +21,11 @@ from pyface.qt import QtCore, QtGui
 from traits.api import Instance, on_trait_change
 
 # Local imports.
-from split_tab_widget import SplitTabWidget
 from pyface.message_dialog import error
 from pyface.workbench.i_workbench_window_layout import \
         MWorkbenchWindowLayout
+from .split_tab_widget import SplitTabWidget
+import six
 
 
 # Logging.
@@ -130,8 +131,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
 
     def close(self):
         # Don't fire signals for editors that have destroyed their controls.
-        QtCore.QObject.disconnect(self._qt4_editor_area,
-                QtCore.SIGNAL('hasFocus'), self._qt4_editor_focus)
+        self._qt4_editor_area.editor_has_focus.disconnect(self._qt4_editor_focus)
 
         self._qt4_editor_area.clear()
 
@@ -143,20 +143,14 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
     def create_initial_layout(self, parent):
         self._qt4_editor_area = editor_area = SplitTabWidget(parent)
 
-        QtCore.QObject.connect(editor_area, QtCore.SIGNAL('hasFocus'),
-                               self._qt4_editor_focus)
+        editor_area.editor_has_focus.connect(self._qt4_editor_focus)
 
         # We are interested in focus changes but we get them from the editor
         # area rather than qApp to allow the editor area to restrict them when
         # needed.
-        QtCore.QObject.connect(
-            editor_area, QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
-            self._qt4_view_focus_changed)
-
-        QtCore.QObject.connect(self._qt4_editor_area,
-                QtCore.SIGNAL('tabTextChanged(QWidget *, QString)'),
-                self._qt4_editor_title_changed)
+        editor_area.focus_changed.connect(self._qt4_view_focus_changed)
 
+        editor_area.tabTextChanged.connect(self._qt4_editor_title_changed)
         editor_area.new_window_request.connect(self._qt4_new_window_request)
         editor_area.tab_close_request.connect(self._qt4_tab_close_request)
         editor_area.tab_window_changed.connect(self._qt4_tab_window_changed)
@@ -202,7 +196,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
         view_ids = [v.id for v in self.window.views if self.contains_view(v)]
 
         # Everything else is provided by QMainWindow.
-        state = str(self.window.control.saveState())
+        state = self.window.control.saveState()
 
         return (0, (view_ids, state))
 
@@ -292,7 +286,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
         self._qt4_editor_area.restoreState(editor_layout, resolve_id)
 
     def get_toolkit_memento(self):
-        return (0, dict(geometry=str(self.window.control.saveGeometry())))
+        return (0, {'geometry' : self.window.control.saveGeometry()})
 
     def set_toolkit_memento(self, memento):
         if hasattr(memento, 'toolkit_data'):
@@ -304,6 +298,8 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
                     if geometry is not None:
                         self.window.control.restoreGeometry(geometry)
 
+    def is_editor_area_visible(self):
+        return self._qt4_editor_area.isVisible()
 
     ###########################################################################
     # Private interface.
@@ -320,7 +316,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
     def _qt4_editor_title_changed(self, control, title):
         """ Handle the title being changed """
         for editor in self.window.editors:
-            if editor.control == control: editor.name = unicode(title)
+            if editor.control == control: editor.name = six.text_type(title)
 
     def _qt4_editor_tab_spinner(self, editor, name, new):
         # Do we need to do this verification?
@@ -336,7 +332,8 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
     def _qt4_active_editor_changed(self, old, new):
         """ Handle change of active editor """
         # Reset tab title to foreground color
-        self._qt4_editor_area.setTabTextColor(new.control)
+        if new is not None:
+            self._qt4_editor_area.setTabTextColor(new.control)
 
     def _qt4_view_focus_changed(self, old, new):
         """ Handle the change of focus for a view. """
@@ -466,7 +463,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             try:
                 dwa = _EDIT_AREA_MAP[position]
             except KeyError:
-                raise ValueError, "unknown view position: %s" % position
+                raise ValueError("unknown view position: %s" % position)
 
             mw.addDockWidget(dwa, dw)
         elif position == 'with':
@@ -478,7 +475,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             try:
                 orient, swap = _VIEW_AREA_MAP[position]
             except KeyError:
-                raise ValueError, "unknown view position: %s" % position
+                raise ValueError("unknown view position: %s" % position)
 
             mw.splitDockWidget(rel_dw, dw, orient)
 
@@ -501,10 +498,9 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             dw = QtGui.QDockWidget(view.name, self.window.control)
             dw.setWidget(_ViewContainer(size, self.window.control))
             dw.setObjectName(view.id)
-            dw.connect(dw.toggleViewAction(), QtCore.SIGNAL('toggled(bool)'),
-                    self._qt4_handle_dock_visibility)
-            dw.connect(dw, QtCore.SIGNAL('visibilityChanged(bool)'),
-                    self._qt4_handle_dock_visibility)
+            dw.toggleViewAction().toggled.connect(
+                self._qt4_handle_dock_visibility)
+            dw.visibilityChanged.connect(self._qt4_handle_dock_visibility)
 
             # Save the dock window.
             view._qt4_dock = dw
@@ -520,7 +516,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             view.window = self.window
 
             try:
-                view.control = view.create_control(self.window.control)
+                view.control = view.create_control(dw.widget())
             except:
                 # Tidy up if the view couldn't be created.
                 delattr(view, '_qt4_dock')
