@@ -18,7 +18,7 @@
 """
 
 # Enthought library imports.
-from traits.api import Any, HasTraits, provides
+from traits.api import Any, Bool, HasTraits, provides
 
 # Local imports.
 from pyface.i_widget import IWidget, MWidget
@@ -30,20 +30,49 @@ class Widget(MWidget, HasTraits):
     interface for the API documentation.
     """
 
+    # 'IWidget' interface ----------------------------------------------------
 
-    #### 'IWidget' interface ##################################################
-
+    #: The toolkit specific control that represents the widget.
     control = Any
 
+    #: The control's optional parent control.
     parent = Any
 
-    ###########################################################################
+    #: Whether or not the control is visible
+    visible = Bool(True)
+
+    #: Whether or not the control is enabled
+    enabled = Bool(True)
+
+    # ------------------------------------------------------------------------
     # 'IWidget' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
+
+    def show(self, visible):
+        """ Show or hide the widget.
+
+        Parameter
+        ---------
+        visible : bool
+            Visible should be ``True`` if the widget should be shown.
+        """
+        self.visible = visible
+        if self.control is not None:
+            self.control.Show(visible)
+
+    def enable(self, enabled):
+        """ Enable or disable the widget.
+
+        Parameter
+        ---------
+        enabled : bool
+            The enabled state to set the widget to.
+        """
+        self.enabled = enabled
+        if self.control is not None:
+            self.control.Enable(enabled)
 
     def destroy(self):
         if self.control is not None:
             self.control.Destroy()
             self.control = None
-
-#### EOF ######################################################################
