@@ -6,7 +6,7 @@ import pyface.action.api as pyface
 from traits.api import Instance
 
 # Local imports.
-from action_controller import ActionController
+from .action_controller import ActionController
 
 
 class ToolBarManager(pyface.ToolBarManager):
