@@ -2,7 +2,7 @@
 
 
 # Standard library imports.
-import cPickle
+import six.moves.cPickle
 import logging
 import os
 
@@ -14,11 +14,11 @@ from traits.api import Instance, List, Unicode, Vetoable
 from traits.api import VetoableEvent
 
 # Local imports.
-from i_editor_manager import IEditorManager
-from i_workbench import IWorkbench
-from user_perspective_manager import UserPerspectiveManager
-from workbench_window import WorkbenchWindow
-from window_event import WindowEvent, VetoableWindowEvent
+from .i_editor_manager import IEditorManager
+from .i_workbench import IWorkbench
+from .user_perspective_manager import UserPerspectiveManager
+from .workbench_window import WorkbenchWindow
+from .window_event import WindowEvent, VetoableWindowEvent
 
 
 # Logging.
@@ -315,8 +315,8 @@ class Workbench(HasTraits):
                 # If the memento class itself has been modified then there
                 # is a chance that the unpickle will fail. If so then we just
                 # carry on as if there was no memento!
-                f = file(filename, 'r')
-                memento = cPickle.load(f)
+                f = open(filename, 'rb')
+                memento = six.moves.cPickle.load(f)
                 f.close()
 
                 # The memento doesn't actually get used until the window is
@@ -334,8 +334,8 @@ class Workbench(HasTraits):
         """ Save the window layout. """
 
         # Save the window layout.
-        f = file(os.path.join(self.state_location, 'window_memento'), 'w')
-        cPickle.dump(window.get_memento(), f)
+        f = open(os.path.join(self.state_location, 'window_memento'), 'wb')
+        six.moves.cPickle.dump(window.get_memento(), f)
         f.close()
 
         return
