@@ -17,6 +17,7 @@ wxPython's wxStyledTextCtrl. The latest files are always available at the
 SourceForge project page at http://sourceforge.net/projects/pycrust/.
 Sponsored by Orbtech - Your source for Python programming expertise."""
 
+from __future__ import print_function
 __author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
 __cvsid__ = "$Id: shell.py,v 1.2 2003/06/13 17:59:34 dmorrill Exp $"
 __revision__ = "$Revision: 1.2 $"[11:-2]
@@ -30,8 +31,8 @@ from wx.py.pseudo import PseudoFileIn, PseudoFileOut, PseudoFileErr
 from wx.py.version import VERSION
 
 # local imports
-from drag_and_drop import PythonObject
-from drag_and_drop import clipboard as enClipboard
+from .drag_and_drop import PythonObject
+from .drag_and_drop import clipboard as enClipboard
 
 sys.ps3 = '<-- '  # Input prompt.
 
@@ -123,15 +124,15 @@ F9                Pop-up window of matching History items.
         if hasattr(self.other, name):
             return getattr(self.other, name)
         else:
-            raise AttributeError, name
+            raise AttributeError(name)
 
     def __setattr__(self, name, value):
-        if self.__dict__.has_key(name):
+        if name in self.__dict__:
             self.__dict__[name] = value
         elif hasattr(self.other, name):
             return setattr(self.other, name, value)
         else:
-            raise AttributeError, name
+            raise AttributeError(name)
 
     def _getAttributeNames(self):
         """Return list of magic attributes to extend introspection."""
@@ -276,8 +277,8 @@ class Shell(wxStyledTextCtrl):
 
         This simply sets "close", "exit" and "quit" to a helpful string.
         """
-        import __builtin__
-        __builtin__.close = __builtin__.exit = __builtin__.quit = \
+        import six.moves.builtins
+        six.moves.builtins.close = six.moves.builtins.exit = six.moves.builtins.quit = \
             'Click on the close button to leave the application.'
 
     def quit(self):
@@ -300,7 +301,7 @@ class Shell(wxStyledTextCtrl):
         if startupScript and os.path.isfile(startupScript):
             startupText = 'Startup script executed: ' + startupScript
             self.push('print %s;execfile(%s)' % \
-                      (`startupText`, `startupScript`))
+                      ('startupText', 'startupScript'))
         else:
             self.push('')
 
@@ -603,10 +604,10 @@ class Shell(wxStyledTextCtrl):
         # to the beginning if we don't find anything.
         if (self.historyIndex <= -1) \
         or (self.historyIndex >= len(self.history)-2):
-            searchOrder = range(len(self.history))
+            searchOrder = list(range(len(self.history)))
         else:
-            searchOrder = range(self.historyIndex+1, len(self.history)) + \
-                          range(self.historyIndex)
+            searchOrder = list(range(self.historyIndex+1, len(self.history))) + \
+                          list(range(self.historyIndex))
         for i in searchOrder:
             command = self.history[i]
             if command[:len(searchText)] == searchText:
@@ -623,7 +624,7 @@ class Shell(wxStyledTextCtrl):
 
         # This method will most likely be replaced by the enclosing app
         # to do something more interesting, like write to a status bar.
-        print text
+        print(text)
 
     def insertLineBreak(self):
         """Insert a new line break."""
@@ -1363,4 +1364,3 @@ class ShellMenu:
             event.Check(self.crust.filling.fillingTree.showDoc)
         elif id == ID_FILLING_SHOW_MODULE:
             event.Check(self.crust.filling.fillingTree.showModule)
-
